%% ==============================
\chapter{Introduction}
\label{ch:Introduction}
%% ==============================

%Functional Programming and Haskell in special have become more popular
%recently, as can for example be seen by the inclusion of their teaching into
%the compulsory courses of a Bachelors degree at the Karlsruhe Institute of
%Technology.

%Many programmers are more familiar with imperative and object oriented
%programming languages and their styles of data structures and evaluation.


%To learn Haskell it is vital to understand
%
%Some tools have been developed to accomodate this.
%
%In this thesis I will be looking at ... and evaluate ...

%% ===========================
%\section{Research Aims}
%\label{ch:Content1:sec:Section1}
%% ===========================

%Functional programming languages like Haskell are often seen as unintuitive and
%difficult to learn by newcomers who are used to the imperative programming
%paradigm. In imperative programming states get altered by an explicit sequence
%of actions, while in functional programming the programmer describes the
%relations between variables, often leaving the order of evaluation undefined.
%This promotes more abstract programming, but may lead to unexpected space and
%runtime behavior that is hard to understand and debug.

%As part of this thesis I have created ghc-vis, a library and tool to visualize
%lazy evaluation and sharing in Haskell programs and GHC's interactive
%environment. I will describe the motivation behind ghc-vis, explain the
%underlying principles and evaluate how ghc-vis can be used to learn about data
%structures and how it compares to other methods of visualization.

%Functional programming languages like Haskell are often seen as unintuitive and
%difficult to learn by newcomers who are used to the imperative programming
%paradigm.

%Functional programming offers a way to write compact, easy to understand

%The motivation of this thesis is to 

Functional programming languages like Haskell offer a way to write
well-structured software, which is easy to understand and still performs well.
In order to achieve this one has to be able to consciously use features that
result from the paradigm of functional programming.

This thesis aims to provide a tool for visualizing two features of this kind,
namely lazy evaluation and sharing, in a way that can be used in the
(self-)teaching of Haskell and the development and debugging of Haskell
software.

A common example for the power of lazy evaluation are infinite data structures.
They are easy to define and convenient to use in Haskell. We can write
\begin{code}
ones = [1,1..]
\end{code}
to construct an infinite list of |1|s, which we can now access by the
suggestive name |ones|. How does this work? Clearly the entire list can't be
stored in memory as we do not possess the infinite tape of a turing machine.

We can write a function to retrieve the |n|th member of a list:
\begin{code}
at  0  (x:xs)  =  x
at  n  (x:xs)  =  at (n-1) xs
\end{code}
Evaluating |at 2 ones| extracts the second member of the list |ones|, which
gives us the integer |1|. In the same manner |at 3 ones| and |at 4 ones| give
us |1|. But what is happening to the infinite list of |ones| as we access its
members?

\begin{figure} [ht]
  \begin{subfigure}[t]{.27\textwidth}
    \centering
    \includegraphics[scale=.4]{images/intro-1-1.pdf}
    \caption{After |at 2 ones|}
  \end{subfigure}
  \begin{subfigure}[t]{.31\textwidth}
    \centering
    \includegraphics[scale=.4]{images/intro-1-2.pdf}
    \caption{After |at 3 ones|}
  \end{subfigure}
  \begin{subfigure}[t]{.38\textwidth}
    \centering
    \includegraphics[scale=.4]{images/intro-1-3.pdf}
    \caption{After |at 4 ones|}
  \end{subfigure}
  \caption{Infinite list of |ones| gets lazily evaluated}\label{fig:intro1}
\end{figure}

Figure~\ref{fig:intro1} provides a view of the actual representation of the
list in memory. The solution is that the infinite list of ones gets constructed
just as we access it. Thinking about this leads us to a problem: When we
evaluate |at (10^7) ones| a huge list gets constructed and a lot of memory is
used to store it. There must be a way to avoid this and indeed there is. We
define the infinite list of ones in a different way:
\begin{code}
ones' = 1 : ones'
\end{code}
The resulting list is the same and we can access it in the same way. But when
we evaluate |at (10^7) ones'| memory usage does not seem to increase at all.
What is the reason?

\begin{figure} [ht]
  \begin{subfigure}[t]{.32\textwidth}
    \centering
    \includegraphics[scale=.4]{images/intro-3.pdf}
    \caption{After |at 2 ones|}
  \end{subfigure}
  \begin{subfigure}[t]{.32\textwidth}
    \centering
    \includegraphics[scale=.4]{images/intro-3.pdf}
    \caption{After |at 3 ones|}
  \end{subfigure}
  \begin{subfigure}[t]{.32\textwidth}
    \centering
    \includegraphics[scale=.4]{images/intro-3.pdf}
    \caption{After |at 4 ones|}
  \end{subfigure}
  \caption{An infinite list of ones that uses constant space}\label{fig:intro2}
\end{figure}

As Figure~\ref{fig:intro2} reveals this time no big list is constructed in
memory, instead a list is created that references itself as the rest of the
list.

The reader may want to experiment with these and the more complex examples
provided later. All the Haskell code used in this thesis is available at
\url{http://felsin9.de/nnis/ghc-vis/thesis}.

The tool developed as part of this thesis, \emph{ghc-vis}, was made available
as an open source package on Hackage:
\url{http://hackage.haskell.org/package/ghc-vis}.

ghc-vis can be easily installed from the command line:
\begin{Verbatim}
$ cabal install ghc-vis
$ echo ":script $HOME/.cabal/share/ghc-vis-0.4/ghci" >> ~/.ghci
\end{Verbatim}
Most testing was done on Linux systems. The Haskell Platform, GTK, Cairo and
Pango have to be installed and Cabal's package list should be updated if any
problems occur during the installation:
\begin{Verbatim}
$ cabal update
$ cabal install gtk2hs-buildtools
\end{Verbatim}
Now ghc-vis can be used inside of \emph{GHCi}:
\begin{Verbatim}
$ ghci
GHCi, version 7.4.2: http://www.haskell.org/ghc/  :? for help
ghci> :vis
ghci> let ones = [1,1..]
ghci> :view ones
\end{Verbatim}
An example for using ghc-vis will be presented in
Subsection~\ref{ss:Demonstration} and further documentation is available at
\url{http://felsin9.de/nnis/ghc-vis}.

%% ===========================
%\section{Organization of this Thesis}
%\label{ch:Content1:sec:Section1}
%% ===========================

%The rest of this thesis is structured as follows:
%
%Chapter~\ref{ch:Background} discusses the Haskell programming language, how
%lazy evaluation and sharing work in it, and how GHC uses the heap to store data
%structures and evaluate functions. Then in chapter~\ref{ch:ghc-vis} the design
%of ghc-vis is presented, explaining the choices made and the problems
%encountered. In chapter~\ref{ch:Evaluation} we evaluate how ghc-vis performs.
%Finally chapter~\ref{ch:Conclusion} concludes the work and discusses
%improvements which are possible in the future.
