\documentclass{thesisclass}
% Based on thesisclass.cls of Timo Rohrberg, 2009
% ----------------------------------------------------------------
% Thesis - Main document
% ----------------------------------------------------------------

%include lhs2TeX.fmt
%include lhs2TeX.sty

%format alpha = "\alpha"
%format beta  = "\beta"
%format gamma = "\gamma"
%format delta = "\delta"
%format forall a = "\forall " a
%format <.> = "."
%format :+: = "\oplus"
%format x1
%format x2
%format a1
%format a2
%format t1
%format t2
%format s1
%format s2

%% -------------------------------
%% |  Information for PDF file   |
%% -------------------------------
\hypersetup{
 pdfauthor={Not set},
 pdftitle={Not set},
 pdfsubject={Not set},
 pdfkeywords={Not set}
}

\newenvironment{abstract}%
{\null\thispagestyle{empty}\vfill\centering\begin{minipage}{0.75\textwidth}\begin{center}%
\bfseries \abstractname\vspace{.5em} \end{center}}%
{\end{minipage}\vspace{5em}\vfill}


%% ---------------------------------
%% | Information about the thesis  |
%% ---------------------------------

\newcommand{\myname}{Dennis Felsing}
\newcommand{\mytitle}{Visualization of\\ 
											Lazy Evaluation and Sharing}
\newcommand{\myinstitute}{Institute for Program Structures\\
													and Data Organization (IPD)}

\newcommand{\reviewerone}{Prof. Gregor Snelting}
%\newcommand{\reviewertwo}{?}
\newcommand{\advisor}{Joachim Breitner}
%\newcommand{\advisortwo}{?}

\newcommand{\timestart}{2012-05-28}
\newcommand{\timeend}{2012-09-27}
\newcommand{\submissiontime}{2012-09-27}


%% ---------------------------------
%% | ToDo Marker - only for draft! |
%% ---------------------------------
% Remove this section for final version!
\setlength{\marginparwidth}{20mm}

\newcommand{\margtodo}
{\marginpar{\textbf{\textcolor{red}{ToDo}}}{}}

\newcommand{\todo}[1]
{{\textbf{\textcolor{red}{(\margtodo{}#1)}}}{}}


%% --------------------------------
%% | Old Marker - only for draft! |
%% --------------------------------
% Remove this section for final version!
\newenvironment{deprecated}
{\begin{color}{gray}}
{\end{color}}


%% --------------------------------
%% | Settings for word separation |
%% --------------------------------
% Help for separation:
% In german package the following hints are additionally available:
% "- = Additional separation
% "| = Suppress ligation and possible separation (e.g. Schaf"|fell)
% "~ = Hyphenation without separation (e.g. bergauf und "~ab)
% "= = Hyphenation with separation before and after
% "" = Separation without a hyphenation (e.g. und/""oder)

% Describe separation hints here:
\hyphenation{
% Pro-to-koll-in-stan-zen
% Ma-na-ge-ment  Netz-werk-ele-men-ten
% Netz-werk Netz-werk-re-ser-vie-rung
% Netz-werk-adap-ter Fein-ju-stier-ung
% Da-ten-strom-spe-zi-fi-ka-tion Pa-ket-rumpf
% Kon-troll-in-stanz
}

%\usepackage{haskell}

\usepackage{afterpage}

%\usepackage{fancyvrb}
%\DefineVerbatimEnvironment{code}{Verbatim}{fontsize=\small}
%\DefineVerbatimEnvironment{example}{Verbatim}{fontsize=\small}
%\newcommand{\ignore}[1]{}
\usepackage{fancyvrb}
\RecustomVerbatimEnvironment{Verbatim}{Verbatim}{xleftmargin=\mathindent}
%\DefineVerbatimEnvironment{code}{Verbatim}{}

\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{amsthm}

\usepackage{calc}

\usepackage{subcaption}

\usepackage{booktabs}
\usepackage{array} % table cell suffix, prefix
\usepackage{longtable}
\usepackage{tabularx} % easy width

%\usepackage[subrefformat=parens,labelformat=parens]{subfig}

\usepackage{url}

\usepackage{tikz}
\usetikzlibrary{shapes.multipart,chains,positioning,arrows,calc}

%% ------------------------
%% |    Including files   |
%% ------------------------
% Only files listed here will be included!
% Userful command for partially translating the document (for bug-fixing e.g.)
\includeonly{%
titlepage,
declaration,
abstract,
acknowledgements,
introduction,
content,
evaluation,
conclusion,
appendix
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Here, main documents begins %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\begin{document}

% Remove the following line for German text
\selectlanguage{english}

\frontmatter
\pagenumbering{roman}
\include{titlepage}
\include{declaration}
\blankpage

\include{abstract}
\include{acknowledgements}

%% -------------------
%% |   Directories   |
%% -------------------
\tableofcontents
\blankpage


%% -----------------
%% |   Main part   |
%% -----------------
\mainmatter
\pagenumbering{arabic}
%include introduction.lhs
%include content.lhs
%include evaluation.lhs
\include{conclusion}


%% --------------------
%% |   Bibliography   |
%% --------------------
\cleardoublepage
\phantomsection

\backmatter
\addcontentsline{toc}{chapter}{\bibname}

\iflanguage{english}
{\bibliographystyle{IEEEtran}}	% english style
{\bibliographystyle{babalpha-fl}}	% german style
												  
% Use IEEEtran for numeric references
%\bibliographystyle{IEEEtranSA})

\bibliography{thesis}


%% ----------------
%% |   Appendix   |
%% ----------------
\cleardoublepage

%include appendix.lhs


\end{document}
